import pgzrun
from coding_games.controller import Controller
from coding_games.Settings import  *

controller = Controller()


def draw():
    """
    Main "draw" method, if the controller doesnt have a screen property, this method will pass it to the controller as
    well as calling drawing method from a controller
    :return:
    """
    if controller.get_screen() is None:
        controller.set_screen(screen)
    controller.draw()


def update():
    """
    Main "update" method of the app
    """
    controller.update(keyboard)


def on_key_down(key):
    """
    Passing the on key down event to the controller
    :param key: Key that is pressed
    """
    controller.on_key_down(key, keys)

pgzrun.go()



from pgzero.screen import Screen

from coding_games.Dialog import Dialog


class Backpack:
    items = []
    isOpened = False
    _internal_position = 0
    itemPosition = 0
    max_items = 5

    def __iter__(self):
        return self

    def __len__(self):
        return len(self.items)

    def __next__(self):
        """
        :return: Returns the next item in backpack
        """
        while self._internal_position < len(self.items):
            item = self.items[self._internal_position]
            self._internal_position += 1
            return item
        raise StopIteration

    def add_item(self, item):
        """
        Adding items to backpack
        :param item: Item to add to backpack
        """
        if len(self) < self.max_items:
            self.items.append(item)
        else:
            raise Exception("Could not add item, backpack is full")

    def remove_item(self, item):
        """
        Removing item from a game backpack
        :param item: Item to be removed
        """
        try:
            self.items.remove(item)
        except IndexError:
            print("Nothing in backpack")

    def use_item(self):
        """
        Using item from backpack, and then the item is removed from backpack and returned
        """
        try:
            item = self.items[self.itemPosition]
            self.remove_item(item)
            self.hide_backpack()
            item.use_item()
            return item
        except IndexError:
            print("Nothing in backpack")

    def next_position(self):
        """
        Moving active position in drawing dialog forward
        """
        if self.itemPosition == len(self.items) - 1:
            return
        self.itemPosition += 1

    def previous_position(self):
        """
        Moving active position in drawing dialog backward
        """
        if self.itemPosition == 0:
            return
        self.itemPosition -= 1

    def show_backpack(self):
        """
        Opening a backpack
        """
        self.itemPosition = 0
        self.isOpened = True

    def hide_backpack(self):
        """
        Hiding backpack
        """
        self.isOpened = False

    def draw_backpack(self, screen: Screen):
        """
        Drawing a backpack, backpack is displayed as a dialog
        :param screen: screen to be displayed
        """
        if self.isOpened:
            if len(self.items) == 0:
                Dialog.draw_dialog(["Empty"], screen)
            else:
                Dialog.draw_dialog(self.items, screen, active_position=self.itemPosition)







import os
from pathlib import Path

import coding_games

HEIGHT = 768
WIDTH = 1024
# TITLE = 'Dizzy: Trapped'
# DEFAULT_PATH = Path(os.path.dirname(coding_games.__file__))
# ICON = DEFAULT_PATH / 'images' / 'icon.png'



from coding_games.ActorState import ActorState
from coding_games.Direction import Direction



class ActorStanding(ActorState):
    def __init__(self, actor):
        super().__init__(name="standing", image="dizzy-standing.png", actor=actor)

    def update(self, key, world):
        if key.left:
            self.actor.state = ActorMoving(self.actor, Direction.left)
        elif key.space:
            self.actor.state = ActorJumping(self.actor)
        elif key.right:
            self.actor.state = ActorMoving(self.actor, Direction.right)


class ActorMoving(ActorState):
    def __init__(self, actor, direction):
        if direction == Direction.right:
            name = "moving-right"
            dizzy_image = "dizzy-right.png"
        else:
            name = "moving-left"
            dizzy_image = "dizzy-left.png"
        super().__init__(name=name, actor=actor, image=dizzy_image)
        self.direction = direction

    def update(self, key, world):
        if key.left:
            self.actor.state = ActorMoving(self.actor, Direction.left)
        elif key.right:
            self.actor.state = ActorMoving(self.actor, Direction.right)
        elif key.space:
            self.actor.state = ActorJumping(self.actor)
        else:
            self.actor.state = ActorStanding(self.actor)


class ActorJumping(ActorState):
    def __init__(self, actor):
        super().__init__(name="jumping", actor=actor, image= "dizzy_jump.png")

    def update(self, key, world):
        if key.left:
            self.actor.state = ActorMoving(self.actor, Direction.left)
        elif key.right:
            self.actor.state = ActorMoving(self.actor, Direction.right)
        elif key.space:
            self.actor.state = ActorJumping(self.actor)
        else:
            self.actor.state = ActorStanding(self.actor)


class ActorFalling(ActorState):
    def __init__(self, actor):
        super().__init__(name="falling", actor=actor, image= "dizzy-standing.png")

    def update(self, key, world):
        pass



import pgzrun

from coding_games import Level, DizzyActor, WIDTH, HEIGHT

level = Level("lets_get_moving")
dizzy = DizzyActor()
dizzy.pos = (300, 300)


def update():
    dizzy.update(keyboard, level)

def draw():
    screen.clear()
    level.draw()
    dizzy.draw()

pgzrun.go()



from coding_games import ActorState
from coding_games.AnimatedActor import AnimatedActor
from coding_games.State import State

class Item(AnimatedActor):
    def __init__(self, image, dimensions, state: State = State(), name='item'):
        super().__init__(image, name=name, state=state, sprite=dimensions)

    def update(self):
        pass

    def use_item(self):
        pass

    def __str__(self):
        return self.name




class LevelChain:
    level = None
    # MAP rotated + 90 degrees
    #               BASE                    1st floor                       2nd floor
    # level_chain = [[None,                   "castle_treasure",              "castle_roof"],
    #                [None,                   "castle_entry",                 "castle_key"],
    #                [None,                   "green_goblin",                 None],
    #                [None,                   "pink_statue",                  None],
    #                [None,                   "main_level",                   None],
    #                ["cave",                 "golden_lion",                  None],
    #                ["side_walk",            "clouds",                       None],
    #                ["boat_passage",         "cherry_in_clouds",             "heaven"],
    #                ["green_wizard",         "black_sky",                    "heaven_clouds"],
    #                ["pink_mouse",           "pink_bottle",                  "upper_stairs"],
    #                ["dungeon_pond",         "clouds_to_the_dungeon",        None],
    #                ["dungeon_entry",        "cloud_above_dungeons_entry",   None],
    #                ["dungeon_green_shield", "dungeon_dizzy",                None],
    #                [None,                   "dungeon_red_floor",            "dungeon_bedroom"]]

    def __init__(self, level_chain, initial_position: tuple = (0, 0)):
        self.level_position = initial_position
        if not level_chain:
            raise Exception("LevelCreator must have minimum of 1 level...")
        self.level_chain = level_chain
        self.set_new_level(self.level_position)

    def set_new_level(self, new_position: tuple):
        """
        Sets a new level based on position
        :param new_position: new level position
        :return: True if there is a level at that position otherwise false
        """
        if new_position[0] < 0 or new_position[1] < 0:
            return False
        try:
            level = self.level_chain[new_position[0]][new_position[1]]
        except IndexError:
            return False
        if level:
            self.level = level
            self.level_position = new_position
            return True
        return False

    def go_up(self):
        """
        Going to level at right on the map
        :return: True if there is a level otherwise False
        """
        new_position: tuple = self.level_position[0] + 1, self.level_position[1]
        return self.set_new_level(new_position)


    def go_down(self):
        """
        Going to level at left on the map
        :return: True if there is a level otherwise False
        """
        new_position: tuple = self.level_position[0] - 1, self.level_position[1]
        return self.set_new_level(new_position)

    def go_right(self):
        """
        Going to level at up on the map
        :return: True if there is a level otherwise False
        """
        new_position: tuple = self.level_position[0], self.level_position[1] + 1
        return self.set_new_level(new_position)

    def go_left(self):
        """
        Going to level at down on the map
        :return: True if there is a level otherwise False
        """
        new_position: tuple = self.level_position[0], self.level_position[1] - 1
        return self.set_new_level(new_position)



import pytmx
from pgzero import game

from coding_games.utils.ObjectCreator import Creator


class Level:
    map = None

    def __init__(self, name: str):
        self.load_level(name)
        self.items = Creator.create_items_from_map(self.map, self)
        self.actors = Creator.create_actors(self.map)

        self.name = name
        self.walls = Creator.create_walls(self.map)
        self.width = 32
        self.height = 24

    def load_level(self, name: str):
        self.map = pytmx.load_pygame("maps/{}.tmx".format(name))

    def get_map(self):
        return self.map

    def get_items(self):
        return self.items

    def get_actors(self):
        return self.actors

    def __str__(self):
        return self.name

    def get_walls(self):
        return self.walls

    def draw_background(self, ):
        y = 0
        for row in range(self.height):
            x = 0
            for col in range(0, self.width):
                image = self.map.get_tile_image(col, row, 0)
                if image is not None:
                    game.screen.blit(image,
                                      (x * self.map.tilewidth,
                                       y * self.map.tileheight,),)
                x += 1
            y += 1

    def draw_items(self,):
        for item in self.get_items():
            item.draw()

    def draw_actors(self,):
        for actor in self.get_actors():
            actor.draw()

    def draw(self):
        self.draw_background()
        self.draw_items()
        self.draw_actors()

    def update(self, key):
        for actor in self.actors:
            actor.update(key, self)



import pygame
from pgzero.rect import Rect
from pgzero.screen import Screen


# Dialog stores simple data like lines to display and width of dialog
class Dialog:
    # Color (x,y,z) -> numbers from 0 to 255
    def __init__(self, lines, width, color):
        self.lines = lines
        self.width = width
        self.color = color

    def draw(self, screen):
        Dialog.draw_dialog(self.lines, screen=screen, width=self.width, color=self.color)

    # Drawing dialog, dialog height may differ as the items length differs
    @staticmethod
    def draw_dialog(lines, screen: Screen, active_position=-1, width=14, color=(0, 255, 0)):
        def draw_horizontal_border(height, width_of_dialog, border_color):
            screen.draw.filled_rect(
                Rect((screen.width / 2 - ((width_of_dialog // 2 + 1) * 32), height - 32),
                     (((width_of_dialog + 2) * 32), 32)), border_color)

            image = pygame.transform.rotate(pygame.image.load("images/dialog_end.png"), 90)
            screen.blit(image, (screen.width / 2 - ((width_of_dialog // 2 + 1) * 32), height - 32))
            screen.blit(pygame.image.load("images/dialog_cross.png"), (screen.width / 2 - ((width_of_dialog // 2) * 32), height - 32))
            for i in range((width_of_dialog - 2) // 2):
                image = pygame.transform.rotate(pygame.image.load("images/dialog_middle.png"), 90)
                screen.blit(image, (screen.width / 2 - ((i + 1) * 32), height - 32))
                screen.blit(image, (screen.width / 2 + (i * 32), height - 32))
            screen.blit(pygame.image.load("images/dialog_cross.png"),
                        (screen.width / 2 + (((width_of_dialog // 2) - 1) * 32), height - 32))
            image = pygame.transform.rotate(pygame.image.load("images/dialog_start.png"), 90)
            screen.blit(image, (screen.width / 2 + ((width_of_dialog // 2) * 32), height - 32))

        width_of_dialog = width
        height_of_dialog = screen.height / 2

        draw_horizontal_border(height_of_dialog, width_of_dialog, color)

        for i in range(len(lines)):
            screen.draw.filled_rect(
                Rect((screen.width / 2 - ((width_of_dialog // 2) * 32), height_of_dialog + (i * 32)), (32,32)),
                color)
            image = pygame.transform.rotate(pygame.image.load("images/dialog_middle.png"), 180)
            screen.blit(image, (screen.width / 2 - ((width_of_dialog // 2) * 32), height_of_dialog + (i * 32)))
            screen.draw.filled_rect(
                Rect((screen.width / 2 - ((width_of_dialog // 2 - 1) * 32), height_of_dialog + (i * 32)),
                     ((width_of_dialog - 2) * 32, 32)),
                (0, 0, 0))

            screen.draw.text(str(lines[i]), fontname="dizzy-iii-fantasy-world-dizzy-spectrum", fontsize=16,
                             centerx=screen.width / 2, top=height_of_dialog + (i * 32) + 8,
                             color=(0, 0, 255) if active_position == i else (255, 255, 255))

            screen.draw.filled_rect(
                Rect((screen.width / 2 + (width_of_dialog//2 - 1) * 32, height_of_dialog + (i * 32)), (32, 32)),
                color)
            screen.blit(pygame.image.load("images/dialog_middle.png"),
                        (screen.width / 2 + (width_of_dialog//2 - 1) * 32, height_of_dialog + (i * 32)))

        draw_horizontal_border(height_of_dialog + (len(lines) + 1) * 32, width_of_dialog, color)



import pgzrun

from coding_games import Level, DizzyActor, WIDTH, HEIGHT, ICON, Flare, Backpack, Item, Dialog, Hud, AnimatedActor
from coding_games.Usable import UsableItem

level = Level("moving_things")


class Leaves(UsableItem):
    def __init__(self, image='leaves', name='leaves', dimensions=(64, 32), *args, **kwargs):
        super().__init__(image, name, dimensions, *args, **kwargs)

    def can_be_used(self, items: list):
        return True

    def use(self, items: list):
        super().use(items)


class Matches(UsableItem):
    def __init__(self, image='matches', name='matches', dimensions=(64, 64), *args, **kwargs):
        super().__init__(image, name, dimensions, *args, **kwargs)

    def can_be_used(self, items: list):
        if leaves in self.colliding_items(items) and leaves.can_be_used(items):
            print('Can be used')
            return True
        return False

    def use(self, items):
        print("Using item")
        items.remove(leaves)
        fire = AnimatedActor(name='fire', image='fire', sprite=(64, 32))
        fire.pos = self.pos
        level.items.append(fire)
        super().use(items)


flare = Flare()
flare.pos = (350, 350)
backpack = Backpack()
dizzy = level.actors[0]
matches = Matches()
matches.pos = (400, 450)
level.items.append(matches)

leaves = Leaves()
leaves.pos = (550, 450)
level.items.append(leaves)

dialog = Dialog(["Hello I'm Dizzy", "Let's play a game"], color=(100, 244, 200), width=14)

hud = Hud(hp_percentage=100, lives=3)


def update():
    level.update(keyboard)


def on_key_down(key):
    if (key == keys.B):
        backpack.isOpened = not backpack.isOpened

    if (key == keys.G):
        item = dizzy.grabItem(level.items)
        if item is not None:
            level.items.remove(item)
            backpack.add_item(item)

    # if (key == keys.U):
    #     matches.use(level.get_items())

    if backpack.isOpened:
        if key == key.DOWN:
            backpack.next_position()
        if key == key.UP:
            backpack.previous_position()
        if key == key.RETURN:
            item = backpack.use_item()
            if item is not None:
                level.items.append(item)
                item.pos = dizzy.pos
                if isinstance(item, UsableItem):
                    # check ci sa da pouzit
                    if item.can_be_used(level.items):
                        item.use(level.items)
        return


def draw():
    screen.clear()
    level.draw()
    flare.draw()
    if backpack.isOpened:
        backpack.draw_backpack(screen=screen)

    # dialog.draw(screen)
    hud.draw(screen=screen, title="Dizzy locked..")


pgzrun.go()



from coding_games.State import State


class GamePaused(State):
    def __init__(self, world):
        super().__init__()
        self.name = "paused"

    def update(self, key, world):
        pass


class GameActive(State):
    def __init__(self, world):
        super().__init__()
        self.name = "active"

    def update(self, key, world):
        pass


# there should be stored a state of the app (level)
# Controller should control the transition from one level to another
from pgzero.actor import Actor
from pgzero.screen import Screen

from coding_games.Backpack import Backpack
from coding_games.Dialog import Dialog
from coding_games.Hud import Hud
from coding_games.Level import Level
from coding_games.utils.LevelChain import LevelChain

from coding_games.GameState import *


class Controller:
    _screen = None
    _backpack = Backpack()
    dialogs = []
    # dialogs = [Dialog(["Hello my name is Dizzy", "Come and play"], 18, color=(128,0,0))]
    hud = Hud(hp_percentage=100, lives=3)

    def __init__(self):
        self.level_creator = LevelChain([[Level("main_level"), Level("side_walk")]])
        self.top = 0
        self.width = 32
        self.height = 24
        self.left = 0
        self.state = GameActive(self.level_creator.level)

    def set_screen(self, screen: Screen):
        self._screen = screen

    def get_screen(self):
        return self._screen

    def update(self, key):
        if self.state.__str__() == GameActive(self.level_creator.level).__str__():
            self.level_creator.level.update(key)


    def on_key_down(self, key, keys):
        if key == keys.B:
            if not self._backpack.isOpened:
                self.state = GamePaused(self.level_creator.level)
                self._backpack.show_backpack()
                return

        if self._backpack.isOpened:
            if key == keys.B:
                self._backpack.hide_backpack()
                self.state = GameActive(self.level_creator.level)
            if key == keys.DOWN:
                self._backpack.next_position()
            if key == keys.UP:
                self._backpack.previous_position()
            if key == keys.RETURN:
                self._backpack.use_item()
            return

        # LEVEL Movement
        if key == keys.A:
            if self.level_creator.go_left():
                print("Going left")
        elif key == keys.D:
            if self.level_creator.go_right():
                print("Going right")
        elif key == keys.W:
            if self.level_creator.go_up():
                print("Going up")
        elif key == keys.S:
            if self.level_creator.go_down():
                print("Going down")

        # TODO testing -------------------------------
        if key == keys.B:
            self._backpack.add_item(Item(name="Showel", actor=Actor("showel")))

        if key == keys.Q:
            self.level_creator.level.add_to_items_added(Cherry(Actor("cherry")), 50, 50)

        # TODO testing -------------------------------

    def draw(self):
        self._screen.clear()

        view_offset_x = 0
        view_offset_y = 0

        # draw info panel
        self.hud.draw(self._screen, self.level_creator.level.__str__())

        # drawing level
        self.level_creator.level.draw()

        # Drawing backpack when the backpack is opened
        if self._backpack.isOpened:
            self._backpack.draw_backpack(self._screen)

        # Drawing dialogs
        for dialog in self.dialogs:
            Dialog.draw_dialog(screen=self._screen, lines=dialog.lines, width=dialog.width, color=dialog.color)











from coding_games import Item, State


class UsableItem(Item):
    def __init__(self, image, name, dimensions, *args, **kwargs):
        super().__init__(image=image, name=name, dimensions=dimensions,
                         state=State())

    def can_be_used(self, items: list):
        return False

    def use(self, items: list):
        # after using item, remove it from the world
        items.remove(self)




from pgzero.actor import Actor
from pgzero import game
from time import time
from coding_games import ActorState
from coding_games.State import State

WIDTH = 800


class AnimatedActor(Actor):
    def __init__(self, *args, name: str, sprite: tuple,  state: State = State(), pingpong=False, duration=100, **kwargs):
        super().__init__(*args, **kwargs)
        self.pingpong = pingpong
        self.duration = duration
        self._stopped = False

        self.height = sprite[1]
        self.width = sprite[0]

        self._name = name
        self._state = state

        # prepare frames
        self._frames = []
        for x_offset in range(int(self._orig_surf.get_width() / self.width)):
            surface = self._orig_surf.subsurface((x_offset * self.width, 0, self.width, self.height))
            self._frames.append(surface)

        # frame config
        self._current_frame = 0
        self.frame_duration = self.duration / len(self._frames)
        self.last_frame_update = time() * 1000
        self._next_frame_dx = 1

    def start(self):
        self._stopped = False

    def stop(self):
        self._stopped = True

    @property
    def state(self):
        return self._state

    @state.setter
    def state(self, state: ActorState):
        if self._state.name != state.name:
            self._state = state
            self.set_image(state.image, dimension=(self.width, self.height))

    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value

    @property
    def frames(self):
        return self._frames

    @property
    def current_frame(self):
        return self._current_frame

    @current_frame.setter
    def current_frame(self, index):
        if 0 < index < len(self._frames) - 1:
            raise Exception("Frame index out of range.")
        self._current_frame = index

    def _update_frame(self):
        if not self._stopped:
            now = time() * 1000
            if now - self.last_frame_update > self.frame_duration:
                self.last_frame_update = now
                self._current_frame += self._next_frame_dx

                if self.pingpong:
                    if self._next_frame_dx == 1 and self._current_frame >= len(
                            self._frames) - 1 or self._next_frame_dx == -1 and self._current_frame <= 0:
                        self._next_frame_dx *= -1
                else:
                    if self._current_frame == len(self._frames):
                        self._current_frame = 0

    def set_image(self, image, dimension):
        px, py = self.pos
        tx, ty = self.topleft
        self.image = image
        self.height = dimension[1]
        self.width = dimension[0]
        self._frames = []

        # self._init_position(pos=None, anchor=self.anchor, sprite=dimension)

        # counting that sprites will be same size
        self.pos = (px, py)
        self.topleft = (tx, ty)

        for x_offset in range(int(self._orig_surf.get_width() / self.width)):
            surface = self._orig_surf.subsurface(
                (x_offset * self.width, 0, self.width, self.height))
            self._frames.append(surface)

        # frame config
        self._current_frame = 0
        self.frame_duration = self.duration / len(self._frames)
        self.last_frame_update = time() * 1000
        self._next_frame_dx = 1
        # return self._current_frame

    def draw(self):
        self._update_frame()
        game.screen.blit(self._frames[self._current_frame], self.topleft)

    def colliding_actors(self, actors) -> list:
        x, y = self.center
        actors_in_collision = list(filter(lambda i: ((((i.left <= x <= i.right) and (i.top <= y <= i.bottom)) or (
                (self.left <= i.center[0] <= self.right) and (self.top <= i.center[1] <= self.bottom))) and (
                                                             i.name != self.name)), actors))
        return actors_in_collision

    def colliding_items(self, items) -> list:
        x, y = self.center
        items_in_collision = list(filter(lambda i: ((((i.left <= x <= i.right) and (i.top <= y <= i.bottom)) or (
                (self.left <= i.center[0] <= self.right) and (self.top <= i.center[1] <= self.bottom))) and (
                                                             i.name != self.name)), items))
        return items_in_collision



from coding_games.State import State
from coding_games.AnimatedActor import AnimatedActor


class ActorState(State):
    def __init__(self, name, actor: AnimatedActor, image):
        super().__init__(name)
        self.actor = actor
        self.image = image

    def update(self, key, world):
        pass


from coding_games.ActorState import ActorState
from coding_games.Item import Item
from coding_games.Harmfull import Harmful


class Flare(Item, Harmful):
    def __init__(self):
        super().__init__(image='animated-flare', name='flare', dimensions=(64, 128), state=ActorState(name='burning', actor=self, image='animated-flare'))

    def update(self):
        pass


import pgzrun

from coding_games import Level, WIDTH, HEIGHT, Flare, Backpack, Item, Dialog, Hud

level = Level("moving_things")

flare = Flare()
flare.pos = (350, 350)

backpack = Backpack()

box = Item("crate", (32, 32))
box.pos = (400, 450)


def remove():
    level.items.append(box)
    box.pos = dizzy.pos


box.use_item = remove

level.items.append(box)

dizzy = level.actors[0]

dialog = Dialog(["Hello I'm Dizzy", "Let's play a game", "",  "Your task is to ", "move the things",
                 "to the bottom ", "chamber..", "", "Are you ready?.."], color=(100, 244, 200), width=14)

hud = Hud(hp_percentage=100, lives=3)


def update():
    level.update(keyboard)


def on_key_down(key):
    global dialog
    if key == keys.RETURN:
        if dialog is not None:
            dialog = None

    if key == keys.B:
        backpack.isOpened = not backpack.isOpened

    if key == keys.G:
        item = dizzy.grabItem(level.items)
        if item is not None:
            level.items.remove(item)
            backpack.add_item(item)

    if backpack.isOpened:
        if key == key.DOWN:
            backpack.next_position()
        if key == key.UP:
            backpack.previous_position()
        if key == key.RETURN:
            backpack.use_item()
        return


def draw():
    screen.clear()
    level.draw()
    flare.draw()

    backpack.draw_backpack(screen=screen)

    hud.draw(screen=screen, title="Moving things..")

    if dialog is not None:
        dialog.draw(screen)


pgzrun.go()



import pgzrun

from coding_games import Backpack, WIDTH, HEIGHT, Dialog
from coding_games.Level import Level
from coding_games.utils.LevelChain import LevelChain

backpack = Backpack()

levelchain = LevelChain([[Level("boat_passage"), Level("green_wizard")]])
dizzy = levelchain.level.actors[0]

dialogs = []


def update():
    global dizzy
    levelchain.level.update(keyboard)

    if levelchain.level.name == "boat_passage" and dizzy.pos[0] > 1050:
        levelchain.go_right()
        old_pos = dizzy.pos
        dizzy = levelchain.level.actors[0]
        dizzy.pos = (170, old_pos[1] - 10)

    if levelchain.level.name == "green_wizard" and dizzy.pos[0] < 160:
        levelchain.go_left()
        old_pos = dizzy.pos
        dizzy = levelchain.level.actors[0]
        dizzy.pos = (1000, old_pos[1] - 10)

    if levelchain.level.name == "green_wizard" and dizzy.pos[0] > 950:
        if len(dialogs) == 0:
            dialogs.append(Dialog(["Good job dizzy..", "", "Thank you..."], width=14, color=(255, 230, 200)))


def draw():
    screen.clear()
    levelchain.level.draw()

    for dialog in dialogs:
        dialog.draw(screen)


def on_key_down(key):
    # LEVEL Movement
    if key == keys.A:
        if levelchain.go_left():
            print("Going left")
    elif key == keys.D:
        if levelchain.go_right():
            print("Going right")
    elif key == keys.W:
        if levelchain.go_up():
            print("Going up")
    elif key == keys.S:
        if levelchain.go_down():
            print("Going down")

pgzrun.go()



from pgzero.actor import Actor
from coding_games.Direction import Direction


class Controlable(Actor):
    def __init__(self, image, gravity=False, *args, **kwargs):
        super().__init__(image, **kwargs)
        self.gravity = gravity
        self.jump_progress = 0
        self.jump_direction: Direction = None
        self.is_falling = False

    def can_move(self, walls, direction):
        walls_on_actor_level = list(filter(lambda w: (w.y < self.y < (w.y + w.height)), walls))
        if len(walls_on_actor_level) == 0:
            return True
        if direction == Direction.right:
            pos_x, pos_y = self.midright
            for wall in walls_on_actor_level:
                if round(pos_x + 1) == (wall.x + wall.width):
                    return False
        elif direction == Direction.left:
            pos_x, pos_y = self.midleft
            for wall in walls_on_actor_level:
                if round(pos_x - 1) == (wall.x + wall.width):
                    return False
        return True

    def calculate_y_position(self, walls):
        x, y = self.midbottom
        walls_bellow_actor = list(filter(lambda w: ((w.left <= x <= w.right) and (w.y >= y)), walls))
        if len(walls_bellow_actor) == 0:
            return -1
        else:
            y_position = walls_bellow_actor[0].y
            for wall in walls_bellow_actor:
                if wall.y < y_position:
                    y_position = wall.y
            y_position -= 1
        return y_position

    def jump(self, fixed_y, walls, direction=Direction.up):
        x, y = self.midbottom
        if self.jump_direction is None:
            self.jump_direction = direction
        if self.jump_direction == Direction.up:
            self.y -= 2
            self.jump_progress += 1
            if self.jump_progress == 50:
                self.jump_direction = Direction.down
        elif self.jump_direction == Direction.up_right:
            self.y -= 2
            self.jump_progress += 1
            if self.can_move(walls=walls, direction=Direction.right):
                self.x += 1
            if self.jump_progress == 50:
                self.jump_direction = Direction.down_right
        elif self.jump_direction == Direction.up_left:
            self.y -= 2
            self.jump_progress += 1
            if self.can_move(walls=walls, direction=Direction.left):
                self.x -= 1
            if self.jump_progress == 50:
                self.jump_direction = Direction.down_left
        elif self.jump_direction == Direction.down:
            if (fixed_y is not None and fixed_y > (y + 1)) or (fixed_y is None):
                self.y += 2
                self.jump_progress -= 1
            elif fixed_y <= y:
                self.jump_progress = 0
                self.jump_direction = None
            if self.jump_progress == 0:
                self.jump_direction = None
        elif self.jump_direction == Direction.down_right:
            if (fixed_y is not None and fixed_y > (y + 1)) or (fixed_y is None):
                self.y += 2
                self.jump_progress -= 1
                if self.can_move(walls=walls, direction=Direction.right):
                    self.x += 1
            elif fixed_y <= y:
                self.jump_progress = 0
                self.jump_direction = None
            if self.jump_progress == 0:
                self.jump_direction = None
        elif self.jump_direction == Direction.down_left:
            if (fixed_y is not None and fixed_y > (y + 1)) or (fixed_y is None):
                self.y += 2
                self.jump_progress -= 1
                if self.can_move(walls=walls, direction=Direction.left):
                    self.x -= 1
            elif fixed_y <= y:
                self.jump_progress = 0
                self.jump_direction = None
            if self.jump_progress == 0:
                self.jump_direction = None

    def move(self, direction: Direction, key, world):
        walls = world.get_walls()
        apply_gravity = False
        new_y_position = None
        x, y = self.midbottom
        if self.gravity:
            new_y_position = self.calculate_y_position(walls)
            if new_y_position == -1:
                apply_gravity = True
                self.is_falling = True
            elif (new_y_position is not None) and (new_y_position > y):
                apply_gravity = True
                if new_y_position > (33 + y):
                    self.is_falling = True
            else:
                self.is_falling = False
                apply_gravity = False
        if self.jump_direction is not None:
            self.jump(new_y_position, walls=walls)
        elif self.is_falling:
            self.y += 1
        elif direction is not None and self.can_move(walls=walls, direction=direction) and self.jump_direction is None:
            if direction == Direction.right:
                self.x += 1
                if apply_gravity:
                    self.y += 1
            elif direction == Direction.left:
                self.x -= 1
                if apply_gravity:
                    self.y += 1
            elif direction == Direction.up:
                self.jump(new_y_position, walls=walls, direction=direction)
            elif Direction == Direction.down:
                self.y += 1
            elif direction == Direction.up_right:
                self.jump(new_y_position, direction=direction, walls=walls)
            elif direction == Direction.up_left:
                self.jump(new_y_position, direction=direction, walls=walls)
            self.state.update(key, world)
        elif direction is None and self.jump_direction is None:
            self.state.update(key, world)

    def grabItem(self, items: list):
        return self.colliding_items(items).pop()





import pygame
from pgzero.rect import Rect
from pgzero.screen import Screen



class Hud:
    def __init__(self, lives, hp_percentage):
        self.lives = lives
        self.hp_percentage = hp_percentage



    def draw(self, screen: Screen, title: str):
        self.show_lives(screen, self.hp_percentage, self.lives)
        screen.draw.text(title.replace("_", "-"), fontname="dizzy-iii-fantasy-world-dizzy-spectrum",
                               fontsize=24, top=4 * 32, centerx=32 * 32 / 2)

    def show_lives(self, screen: Screen, percentage: int, lives: int):

        for i in range(lives):
            screen.blit(pygame.image.load('images/health_icon.png'), pos=(i * 48 + 32, 32))

        width = 23 * 32
        height = 1 * 32

        size_of_red_rect = size_of_yellow_rect = 64
        size_of_green_rect = 128

        border_rect = Rect((width-2, height-2), (2 + size_of_red_rect + size_of_yellow_rect + size_of_green_rect, 36))
        screen.draw.rect(border_rect, (0, 0, 200))

        # GREEN is 50% of the bar
        if percentage > 50:
            value_to_show = 100 / (50 / (percentage - 50))
            GREEN = 0, 200, 0
            BOX = Rect((width + size_of_red_rect + size_of_yellow_rect, height),
                       (size_of_green_rect / 100 * value_to_show, 32))
            screen.draw.filled_rect(BOX, GREEN)
            percentage = 50

        # YELLOW is 25% of the bar
        if percentage > 25:
            value_to_show = 100 / (25 / (percentage - 25))
            YELLOW = 200, 200, 0
            BOX = Rect((width + size_of_red_rect, height), (size_of_yellow_rect / 100 * value_to_show, 32))
            screen.draw.filled_rect(BOX, YELLOW)
            percentage = 25

        # RED is 25% of the bar
        if percentage > 0:
            value_to_show = 100 / (25 / percentage)
            RED = 200, 0, 0
            BOX = Rect((width, height), (size_of_red_rect / 100 * value_to_show, 32))
            screen.draw.filled_rect(BOX, RED)


import pgzrun

from coding_games import Level, AnimatedActor, Direction, Hud, WIDTH, HEIGHT, DizzyActor
from coding_games.Harmfull import Harmful
from coding_games.State import State


class Bat(AnimatedActor, Harmful):
    def __init__(self, image, dimensions, state: State = State(), name="bat"):
        super().__init__(image, name=name, state=state, sprite=dimensions)
        self.flight_direction = None
        self.flight_progress = 0

    def update(self):
        self.harm()
        if self.flight_direction is None:
            self.flight_direction = Direction.right
        if self.flight_direction == Direction.right:
            self.x += 1
            self.flight_progress += 1
            if self.flight_progress == 500:
                self.flight_direction = Direction.left
        elif self.flight_direction == Direction.left:
            self.x -= 1
            self.flight_progress -= 1
            if self.flight_progress == 0:
                self.flight_direction = Direction.right

    def harm(self, **kwargs):
        actors = self.colliding_actors(level.get_actors())
        if len(actors) != 0:
            hud.hp_percentage -= 1

    def __str__(self):
        return self.name


hud = Hud(hp_percentage=100, lives=3)
level = Level("lets_get_moving")
dizzy = DizzyActor()
dizzy.pos = (300, 500)
level.actors.append(dizzy)

bat = Bat('bat', (32, 32))
bat.pos = (300, 500)
level.actors.append(bat)


def update():
    dizzy.update(keyboard, level)
    bat.update()


def draw():
    screen.clear()
    level.draw()
    hud.draw(screen=screen, title="Dizzy locked..")
    # dizzy.draw()


pgzrun.go()



from coding_games.DizzyState import ActorStanding
from coding_games.AnimatedActor import AnimatedActor
from coding_games.Controlable import Controlable
from coding_games.Direction import Direction
from pgzero.keyboard import Keyboard


class DizzyActor(AnimatedActor, Controlable):
    def __init__(self, *args, **kwargs):
        super().__init__('dizzy-standing', name='dizzy', sprite=(72, 60), duration=500, pingpong=False, gravity=True, state=ActorStanding(self))

    def update(self, key: Keyboard, world):
        direction = None
        if key.SPACE and key.RIGHT:
            direction = Direction.up_right
        elif key.SPACE and key.LEFT:
            direction = Direction.up_left
        elif key.RIGHT:
            direction = Direction.right
        elif key.LEFT:
            direction = Direction.left
        elif key.SPACE:
            direction = Direction.up
        self.move(direction, key, world)



import pgzrun

from coding_games import Backpack, WIDTH, HEIGHT, AnimatedActor
from coding_games.Level import Level
from coding_games.Usable import UsableItem


class Leaves(UsableItem):
    def __init__(self, image='leaves', name='leaves', dimensions=(64, 32), *args, **kwargs):
        super().__init__(image, name, dimensions, *args, **kwargs)

    def can_be_used(self, items: list):
        return True

    def use(self, items: list):
        super().use(items)


class Matches(UsableItem):
    def __init__(self, image='matches', name='matches', dimensions=(64, 64), *args, **kwargs):
        super().__init__(image, name, dimensions, *args, **kwargs)

    def can_be_used(self, items: list):
        if leaves in self.colliding_items(items) and leaves.can_be_used(items):
            print('Can be used')
            return True
        return False

    def use(self, items):
        print("Using item")
        items.remove(leaves)
        fire = AnimatedActor(name='fire', image='fire', sprite=(64, 32))
        fire.pos = self.pos
        level.items.append(fire)
        super().use(items)


class Jug(UsableItem):
    def __init__(self, image='jug', name='jug', dimensions=(64, 64), *args, **kwargs):
        super().__init__(image, name, dimensions, *args, **kwargs)

    def can_be_used(self, items: list):
        if fire in self.colliding_items(items) and leaves.can_be_used(items):
            print('Can be used')
            return True
        return False

    def use(self, items):
        print("Using item")
        items.remove(leaves)
        fire = AnimatedActor(name='fire', image='fire', sprite=(64, 32))
        fire.pos = self.pos
        level.items.append(fire)
        super().use(items)




backpack = Backpack()

level = Level("locked")

dizzy = level.actors[0]
matches = Matches()
matches.pos = (600, 650)
level.items.append(matches)

leaves = Leaves()
leaves.pos = (850, 550)
level.items.append(leaves)


def update():
    level.update(keyboard)


def draw():
    screen.clear()
    level.draw()
    backpack.draw_backpack(screen=screen)

def on_key_down(key):
    if(key == keys.B):
        backpack.isOpened = not backpack.isOpened

    if(key == keys.G):
        item = dizzy.grabItem(level.items)
        if item is not None:
            level.items.remove(item)
            backpack.add_item(item)

    if backpack.isOpened:
        if key == key.DOWN:
            backpack.next_position()
        if key == key.UP:
            backpack.previous_position()
        if key == key.RETURN:
            backpack.use_item()
        return

pgzrun.go()



import pygame

from coding_games.Item import Item
from coding_games.DizzyActor import DizzyActor
from coding_games.Flare import Flare

from coding_games.items.Wall import Wall


def item_factory(name: str):
    return {
        'Flare': Flare()
    }.get(name, None)


class Creator:
    @staticmethod
    def create_items_from_map(level_map, level):
        """
        Creating items that are stored in the level map
        :param level_map: Map of the level
        :return: Items created
        """
        # TODO This is just messed up... but it works somehow, try different solution next..
        def use_function():
            level.items.append(item_as_actor)
            item_as_actor.pos = level.actors[0].pos

        items = []
        for item in level_map.get_layer_by_name("items"):
            item_as_actor = item_factory(item.name)
            if item_as_actor is None:
                item_as_actor = Item(item.name, (32, 32), name=item.name)
                item_as_actor.use_item = use_function
            item_as_actor._surf = pygame.transform.scale(item_as_actor._surf, (item.width, item.height))

            pos = (item.x + item_as_actor.width / 2, item.y + item_as_actor.height / 2)
            item_as_actor.pos = pos

            items.append(item_as_actor)

        return items

    @staticmethod
    def create_actors(level_map):
        actors = []
        for actor in level_map.get_layer_by_name("actors"):
            if actor.name == "Dizzy":
                pos = (actor.x + actor.width / 2, actor.y + actor.height / 2)
                dizzy = DizzyActor()
                dizzy.pos = pos
                actors.append(dizzy)

        return actors

    @staticmethod
    def create_walls(level_map):
        walls = []
        map_walls = level_map.get_layer_by_name("walls")
        for wall in map_walls.tiles():
            x, y, data = wall
            if data != 0:
                width = 32
                height = 32
                new_wall = Wall(x * width, y * height, width, height)
                walls.append(new_wall)
        return walls



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['coding_games',
 'coding_games.examples.games.1. lets_get_moving',
 'coding_games.examples.games.2. moving_things',
 'coding_games.examples.games.4. time_to_move_the_things_to_the_new_level',
 'coding_games.examples.games.5. dizzy_locked',
 'coding_games.examples.games.6. harmfull actor',
 'coding_games.examples.games.7. usable_item',
 'coding_games.items',
 'coding_games.utils']

package_data = \
{'': ['*'],
 'coding_games': ['examples/games/3. Map creation/*',
                  'fonts/*',
                  'images/*',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/map_images/*',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx'],
 'coding_games.examples.games.1. lets_get_moving': ['fonts/*',
                                                    'images/*',
                                                    'maps/*'],
 'coding_games.examples.games.2. moving_things': ['fonts/*',
                                                  'images/*',
                                                  'maps/*'],
 'coding_games.examples.games.4. time_to_move_the_things_to_the_new_level': ['fonts/*',
                                                                             'images/*',
                                                                             'maps/*'],
 'coding_games.examples.games.5. dizzy_locked': ['fonts/*',
                                                 'images/*',
                                                 'maps/*'],
 'coding_games.examples.games.6. harmfull actor': ['fonts/*', 'maps/*'],
 'coding_games.examples.games.7. usable_item': ['fonts/*',
                                                'images/*',
                                                'maps/*']}

install_requires = \
['PyTMX>=3.31,<4.0', 'matches>=0.0.1,<0.0.2', 'pgzero>=1.2.1,<2.0.0']

setup_kwargs = {
    'name': 'coding-games',
    'version': '0.1.5',
    'description': 'The library to quickly create 2D games based on the game Dizzy - Prince of Yolkfolk.. The documentation can be found here: https://mirka-filcakova.gitbook.io/dizzy/',
    'long_description': None,
    'author': 'Gabriel Adamcak',
    'author_email': 'adamcakg@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



from coding_games.Level import *
from coding_games.Backpack import Backpack
from coding_games.Controlable import *
from coding_games.Hud import Hud
from coding_games.Dialog import Dialog
from coding_games.DizzyActor import *
from coding_games.AnimatedActor import *
from coding_games.Item import *
from coding_games.State import *
from coding_games.ActorState import *
from coding_games.DizzyState import *
from coding_games.Harmfull import *
from coding_games.Flare import *

from coding_games.Settings import *



class Wall:
    def __init__(self, pos_x, pos_y, width, height):
        self.name = 'wall'
        self.x = pos_x
        self.y = pos_y
        self.width = width
        self.height = height
        self.top = pos_y
        self.bottom = pos_y + self.height
        self.right = pos_x + self.width
        self.left = pos_x

    def __str__(self):
        return self.name